Website-Suche

So erlauben Sie den Port durch die Firewall auf AlmaLinux


firewalld ist das Standard-Firewall-Programm, das auf Red Hat Enterprise Linux und seinen abgeleiteten Linux-Distributionen, wie z. B. AlmaLinux, vorinstalliert ist.

Standardmäßig ist die Firewall aktiviert, was bedeutet, dass eine sehr begrenzte Anzahl von Diensten in der Lage ist, eingehenden Datenverkehr zu empfangen. Dies ist eine nette Sicherheitsfunktion, aber es bedeutet, dass der Benutzer sachkundig genug sein muss, um die Firewall zu konfigurieren, wenn er einen neuen Dienst auf dem System installiert, wie z. B. HTTPD oder SSH. Andernfalls können Verbindungen aus dem Internet diese Dienste nicht erreichen.

Anstatt die Firewall auf AlmaLinux vollständig zu deaktivieren, können wir bestimmte Ports durch die Firewall zulassen, wodurch eingehende Verbindungen unsere Dienste erreichen können. In dieser Anleitung sehen wir, wie Sie einen Port durch die Firewall von AlmaLinux zulassen können. Fühlen Sie sich frei zu verfolgen, ob Sie AlmaLinux frisch installiert oder von CentOS auf AlmaLinux migriert haben.

In diesem Tutorial lernen Sie:

  • So lassen Sie einen Port oder Dienst durch die Firewall auf AlmaLinux
  • So laden Sie die Firewall neu, damit die Änderungen wirksam werden
  • So überprüfen Sie, welche Ports und Dienste in der Firewall geöffnet sind
  • So schließen Sie einen Port, nachdem er als offen konfiguriert wurde
  • Befehlsbeispiele für das Zulassen der gebräuchlichsten Ports durch die Firewall

Zulassen eines Ports durch die Firewall auf AlmaLinux

So erlauben Sie einen Port durch die Firewall auf AlmaLinux

Befolgen Sie die untenstehenden Schritt-für-Schritt-Anweisungen, um Ports oder Dienste durch firewalld auf AlmaLinux zuzulassen. Sie erfahren auch, wie Sie die offenen Ports überprüfen, die firewalld konfiguriert hat.

  1. Bei der Suche nach offenen Firewall-Ports unter RHEL 8/CentOS 8 Linux ist es wichtig zu wissen, dass Firewall-Ports auf zwei Arten geöffnet werden können. Zum einen kann der Firewall-Port im Rahmen eines vorkonfigurierten Dienstes geöffnet werden. Nehmen Sie dieses Beispiel, in dem wir den Port für HTTP zur öffentlichen Zone öffnen.

    
    firewall-cmd --zone=public --add-service=http --permanent
    

    Natürlich ist das Hinzufügen des HTTP-Dienstes zu firewalld das Äquivalent zum Öffnen von Port 80.

  2. Zweitens können die Ports direkt als benutzerdefinierte benutzerdefinierte vordefinierte Ports geöffnet werden. Nehmen Sie dieses Beispiel, in dem wir den Port 8080 öffnen.

    
    firewall-cmd --zone=public --add-port 8080/tcp --permanent
    

    Da 8080 kein Dienst zugeordnet ist, müssen wir die Portnummer anstelle eines Dienstnamens angeben, wenn wir diesen Port öffnen möchten.

  3. Um zu überprüfen, welche Service-Ports geöffnet sind, führen Sie den folgenden Befehl aus.

    
    firewall-cmd --zone=public --list-services
    cockpit dhcpv6-client http https ssh
    

    Für die oben genannten Dienste (Cockpit, DHCP, HTTP, HTTPS und SSH) sind die entsprechenden Portnummern geöffnet.

  4. Verwenden Sie diesen Befehl, um zu überprüfen, welche Portnummern geöffnet sind.

    
    firewall-cmd --zone=public --list-ports
    20/tcp 8080/tcp
    

    Die oben genannten Ports 20 und 8080 sind für eingehenden Datenverkehr geöffnet.

  5. Nachdem Sie Ihre Ports und Dienste durch die Firewall gelassen haben, müssen wir firewalld neu laden, damit die Änderungen wirksam werden. Alle Regeln mit der Option --permanent werden nun Teil der Laufzeitkonfiguration. Regeln ohne diese Option werden verworfen.

    
    firewall-cmd --reload
    
  6. Wir können auch eine Liste aller offenen Dienste und Ports sehen, indem wir die Option --list-all verwenden.

    
    firewall-cmd --list-all
    public (active)
      target: default
      icmp-block-inversion: no
      interfaces: ens160
      sources: 
      services: cockpit dhcpv6-client http ssh
      ports: 443/tcp
      protocols: 
      masquerade: no
      forward-ports: 
      source-ports: 
      icmp-blocks: 
      rich rules:
    
  7. Beachten Sie, dass firewalld mit Zonen arbeitet. Je nachdem, welche Zone Ihre Netzwerkschnittstelle(n) verwendet, müssen Sie möglicherweise Ihren zulässigen Port zu dieser bestimmten Zone hinzufügen. Der erste Schritt oben zeigt, wie Sie eine Regel zur "öffentlichen" Zone hinzufügen. Um die Regeln speziell für diese Zone anzuzeigen, verwenden Sie weiterhin die Syntax --zone=.

    
    firewall-cmd --list-all --zone=public
    public (active)
      target: default
      icmp-block-inversion: no
      interfaces: ens160
      sources: 
      services: cockpit dhcpv6-client http ssh
      ports: 443/tcp
      protocols: 
      masquerade: no
      forward-ports: 
      source-ports: 
      icmp-blocks: 
      rich rules:
    
  8. Für den Fall, dass Sie einen der zuvor konfigurierten offenen Ports schließen müssen, können Sie die folgende Befehlssyntax verwenden. In diesem Beispiel schließen wir den Port für HTTPS.

    
    firewall-cmd --zone=public --permanent --remove-service=https
    

Das ist alles, was dazu gehört. Um mehr über firewalld und den Linux-Befehl firewall-cmd zu erfahren, lesen Sie unseren speziellen Leitfaden zur Einführung in firewalld und firewall-cmd.

Beispiele für gängige Ports

Verwenden Sie die folgenden Befehle als einfache Referenz, um einige der gebräuchlichsten Dienste durch die Firewall von AlmaLinux zu ermöglichen.

  1. HTTP durch die Firewall zulassen.

    
    firewall-cmd --zone=public --add-service=http --permanent
    
  2. HTTPS durch die Firewall zulassen.

    
    firewall-cmd --zone=public --add-service=https --permanent
    
  3. Lassen Sie MySQL durch die Firewall zu.

    
    firewall-cmd --zone=public --add-service=mysql --permanent
    
  4. SSH durch die Firewall zulassen.

    
    firewall-cmd --zone=public --add-service=ssh --permanent
    
  5. DNS durch die Firewall zulassen.

    
    firewall-cmd --zone=public --add-service=dns --permanent
    
  6. Lassen Sie PostgreSQL durch die Firewall zu.

    
    firewall-cmd --zone=public --add-service=postgresql --permanent
    
  7. Telnet durch die Firewall zulassen.

    
    firewall-cmd --zone=public --add-service=telnet --permanent
    

Abschließende Gedanken

In dieser Anleitung haben wir gesehen, wie man einen Port oder Dienst durch die Firewall auf AlmaLinux zulässt. Dazu gehörte die Verwendung des Befehls firewall-cmd, der mit firewalld verbunden ist, was den Prozess einfach macht, sobald wir die richtige Syntax kennen. Wir haben auch mehrere Beispiele dafür gesehen, wie viele der gängigsten Dienste durch die Firewall zugelassen wurden. Denken Sie daran, besonders darauf zu achten, in welcher Zone Sie Ihre neuen Regeln anwenden.

Verwandte Artikel: